| read_ankom | R Documentation |
Reads a raw ANKOM RF export file and returns the contents as a data frame.
read_ankom(file)
file |
Path to an ANKOM Excel file. |
This function is typically the first step in the ANKOM workflow:
Import ANKOM data
Import metadata
Process data
Fit kinetic models
The imported data can subsequently be processed
using process_ankom().
A data frame containing raw ANKOM RF data.
read_metadata,
process_ankom,
example_data
files <- example_data()
raw_data <- read_ankom(
files$ankom
)
head(
raw_data
)
# Typical workflow
metadata <- read_metadata(
files$metadata
)
gp <- process_ankom(
raw_data,
metadata,
headspace_ml = 210,
temperature_c = 39
)
head(
gp
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.