View source: R/compare_models.R
| compare_models | R Documentation |
Compares performance metrics across multiple fitted kinetic models.
compare_models(...)
... |
Named fitted model objects. |
Model comparison metrics typically include:
R-squared (R²)
Root Mean Squared Error (RMSE)
Residual Sum of Squares (RSS)
Akaike Information Criterion (AIC)
Bayesian Information Criterion (BIC)
This function helps researchers identify models that provide the best balance between goodness of fit and model complexity.
The resulting comparison table can be used with:
rank_models()
plot_model_performance()
plot_model_rankings()
A data frame summarizing model performance metrics for each fitted model.
rank_models,
compare_models_by_treatment,
plot_model_performance,
plot_model_rankings
files <- example_data()
raw_data <- read_ankom(
files$ankom
)
metadata <- read_metadata(
files$metadata
)
gp <- process_ankom(
raw_data,
metadata,
headspace_ml = 210,
temperature_c = 39
)
groot_fit <- fit_groot(
gp
)
gompertz_fit <- fit_gompertz(
gp
)
comparison <- compare_models(
Groot = groot_fit,
Gompertz = gompertz_fit
)
comparison
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.