| example_data | R Documentation |
Returns paths to example files included with the package.
example_data()
The example dataset can be used to explore package functionality, reproduce examples, and learn rumenGP workflows without requiring external files.
The returned object includes:
Example ANKOM RF data
Example metadata
These files are used throughout the package documentation, examples, and vignettes.
A named list containing file paths to package example data.
read_ankom,
read_metadata,
process_ankom,
fit_groot
files <- example_data()
files
raw_data <- read_ankom(
files$ankom
)
metadata <- read_metadata(
files$metadata
)
gp <- process_ankom(
raw_data,
metadata,
headspace_ml = 210,
temperature_c = 39
)
head(
gp
)
fit <- fit_groot(
gp
)
summary(
fit
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.