plot_gp: Plot Raw Gas Production Curve

View source: R/plot_gp.R

plot_gpR Documentation

Plot Raw Gas Production Curve

Description

Plots observed gas production measurements for an individual bottle.

Usage

plot_gp(data, head)

Arguments

data

A rumen_gp object.

head

Bottle identifier to plot.

Details

This visualization displays the raw gas production profile prior to model fitting and is useful for:

  • Inspecting fermentation dynamics

  • Identifying unusual observations

  • Evaluating data quality

  • Comparing individual bottle profiles

Value

A ggplot2 object.

See Also

plot_fit, plot_residuals, process_ankom

Examples


files <- example_data()

raw_data <- read_ankom(
  files$ankom
)

metadata <- read_metadata(
  files$metadata
)

gp <- process_ankom(
  raw_data,
  metadata,
  headspace_ml = 210,
  temperature_c = 39
)

plot_gp(
  gp,
  head = 1
)


rumenGP documentation built on Oct. 2, 2026, 5:09 p.m.