| plot_gp | R Documentation |
Plots observed gas production measurements for an individual bottle.
plot_gp(data, head)
data |
A |
head |
Bottle identifier to plot. |
This visualization displays the raw gas production profile prior to model fitting and is useful for:
Inspecting fermentation dynamics
Identifying unusual observations
Evaluating data quality
Comparing individual bottle profiles
A ggplot2 object.
plot_fit,
plot_residuals,
process_ankom
files <- example_data()
raw_data <- read_ankom(
files$ankom
)
metadata <- read_metadata(
files$metadata
)
gp <- process_ankom(
raw_data,
metadata,
headspace_ml = 210,
temperature_c = 39
)
plot_gp(
gp,
head = 1
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.