View source: R/plot_model_performance.R
| plot_model_performance | R Documentation |
Visualizes model performance metrics produced by
compare_models().
plot_model_performance(comparison)
comparison |
Output from
|
This plot provides a graphical comparison of competing models using goodness-of-fit statistics.
Typical metrics include:
R-squared (R²)
Root Mean Squared Error (RMSE)
Residual Sum of Squares (RSS)
Akaike Information Criterion (AIC)
Bayesian Information Criterion (BIC)
The visualization helps identify models that balance goodness of fit and model complexity.
A ggplot2 object.
compare_models,
rank_models,
plot_model_rankings
files <- example_data()
raw_data <- read_ankom(
files$ankom
)
metadata <- read_metadata(
files$metadata
)
gp <- process_ankom(
raw_data,
metadata,
headspace_ml = 210,
temperature_c = 39
)
groot_fit <- fit_groot(
gp
)
gompertz_fit <- fit_gompertz(
gp
)
comparison <- compare_models(
Groot = groot_fit,
Gompertz = gompertz_fit
)
plot_model_performance(
comparison
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.