View source: R/plot_residual_comparison.R
| plot_residual_comparison | R Documentation |
Displays residuals from multiple fitted models for a selected bottle.
plot_residual_comparison(..., head)
... |
Fitted model objects. |
head |
Head identifier. |
Residuals are calculated as:
Observed - Predicted
and can be used to evaluate:
Model bias
Systematic prediction errors
Heteroscedasticity
Relative model performance
Models with residuals that are randomly distributed around zero are generally preferred over models showing systematic patterns.
A ggplot2 object.
plot_residuals,
plot_model_comparison,
compare_models,
fit_groot,
fit_gompertz
files <- example_data()
raw_data <- read_ankom(
files$ankom
)
metadata <- read_metadata(
files$metadata
)
gp <- process_ankom(
raw_data,
metadata,
headspace_ml = 210,
temperature_c = 39
)
groot_fit <- fit_groot(
gp
)
gompertz_fit <- fit_gompertz(
gp
)
plot_residual_comparison(
Groot = groot_fit,
Gompertz = gompertz_fit,
head = 1
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.