View source: R/rank_models_by_treatment.R
| rank_models_by_treatment | R Documentation |
Ranks fitted models within each treatment
using performance metrics produced by
compare_models_by_treatment().
rank_models_by_treatment(comparison)
comparison |
Output from
|
Rankings can be based on metrics such as:
R-squared (R²)
Root Mean Squared Error (RMSE)
Residual Sum of Squares (RSS)
Akaike Information Criterion (AIC)
Bayesian Information Criterion (BIC)
This function is useful for identifying the best-performing model within each treatment and for evaluating whether model performance varies among treatments.
A data frame containing model rankings for each treatment and performance metric.
compare_models_by_treatment,
best_model_by_treatment,
model_win_frequency,
rank_models
files <- example_data()
raw_data <- read_ankom(
files$ankom
)
metadata <- read_metadata(
files$metadata
)
gp <- process_ankom(
raw_data,
metadata,
headspace_ml = 210,
temperature_c = 39
)
groot_fit <- fit_groot(
gp
)
gompertz_fit <- fit_gompertz(
gp
)
comparison <- compare_models_by_treatment(
Groot = groot_fit,
Gompertz = gompertz_fit
)
rank_models_by_treatment(
comparison
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.