Summarizes parameter estimates and goodness-of-fit statistics for a fitted EXP0 model.
Usage
# S3 method for class 'exp0_fit'
summary(object, ...)Details
The summary typically includes:
Asymptotic gas production (
Vf)Fractional rate constant (
k)Residual Sum of Squares (RSS)
Root Mean Squared Error (RMSE)
R-squared (R²)
Akaike Information Criterion (AIC)
Bayesian Information Criterion (BIC)
The EXP0 model describes gas production as an exponential approach to an asymptotic gas volume without an explicit lag phase.
Examples
files <- example_data()
raw_data <- read_ankom(
files$ankom
)
metadata <- read_metadata(
files$metadata
)
gp <- process_ankom(
raw_data,
metadata,
headspace_ml = 210,
temperature_c = 39
)
fit <- fit_exp0(
gp
)
#> Warning: Large negative pressure values detected. Minimum PSI = -1.274 . Please inspect the affected bottles.
#> rumenGP data validation passed.
#> Observations: 1752
#> Heads: 24
#> Treatments: 5
summary(
fit
)
#>
#> Exponential model (EXP0) summary
#> --------------------------------
#> Total bottles: 24
#> Successful fits: 24
#> Failed fits: 0
#> Low R-squared (< 0.90): 4
#>