View source: R/summary.logistic_fit.R
| summary.logistic_fit | R Documentation |
Summarizes parameter estimates and goodness-of-fit statistics for a fitted Logistic model.
## S3 method for class 'logistic_fit'
summary(object, ...)
object |
A |
... |
Additional arguments passed to methods. |
The summary typically includes:
Asymptotic gas production (A)
Fractional rate constant (k)
Lag time (lambda)
Residual Sum of Squares (RSS)
Root Mean Squared Error (RMSE)
R-squared (R²)
Akaike Information Criterion (AIC)
Bayesian Information Criterion (BIC)
The Logistic model describes gas production using a sigmoidal curve characterized by:
An initial lag phase
A rapid fermentation phase
A plateau approaching asymptotic gas production
The lag parameter (lambda) determines
the position of the sigmoid along the time axis,
while k controls curve steepness.
A data frame containing parameter estimates and model diagnostics for each fitted bottle.
fit_logistic,
fit_gompertz,
plot_fit,
plot_residuals,
compare_models
files <- example_data()
raw_data <- read_ankom(
files$ankom
)
metadata <- read_metadata(
files$metadata
)
gp <- process_ankom(
raw_data,
metadata,
headspace_ml = 210,
temperature_c = 39
)
fit <- fit_logistic(
gp
)
summary(
fit
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.