View source: R/validate_ankom.R
| validate_ankom | R Documentation |
Performs quality-control checks on a
rumen_gp object.
validate_ankom(data)
data |
A |
Supported data sources include datasets created by:
process_ankom()
as_rumen_gp()
Validation checks may include:
Required columns
Missing values
Duplicate observations
Time ordering
Gas production values
ANKOM-specific pressure checks
ANKOM-specific checks are performed only when
Gas_PSI is available.
This function is useful for confirming that a dataset is suitable for downstream modeling, visualization, and model comparison workflows.
The validated rumen_gp object.
process_ankom,
as_rumen_gp,
validate_metadata
files <- example_data()
raw_data <- read_ankom(
files$ankom
)
metadata <- read_metadata(
files$metadata
)
gp <- process_ankom(
raw_data,
metadata,
headspace_ml = 210,
temperature_c = 39
)
validate_ankom(
gp
)
# Validation also supports datasets
# created using as_rumen_gp()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.